@@ -15,7 +15,7 @@ use vrp_core::construction::heuristics::InsertionContext;
 use vrp_core::models::common::SingleDimLoad;
 use vrp_core::models::problem::ProblemObjective;
 use vrp_core::prelude::*;
-use vrp_core::rosomaxa::evolution::{InitialOperator, Telemetry, TelemetryMode};
+use vrp_core::rosomaxa::evolution::{InitialOperator, TelemetryMode};
 use vrp_core::rosomaxa::get_default_selection_size;
 use vrp_core::rosomaxa::prelude::*;
 use vrp_core::rosomaxa::utils::*;
@@ -77,20 +77,18 @@ pub enum PopulationType {
         selection_size: Option<usize>,
         /// Elite population size. Default is 2.
         max_elite_size: Option<usize>,
-        /// Node population size. Default is 2.
+        /// Node population size. Default is 4.
         max_node_size: Option<usize>,
-        /// Spread factor. Default is 0.25.
+        /// Spread factor. Default is 0.75.
         spread_factor: Option<f64>,
-        /// Distribution factor. Default is 0.25.
+        /// Distribution factor. Default is 0.75.
         distribution_factor: Option<f64>,
-        /// Objective reshuffling. Default is 0.05.
+        /// Objective reshuffling. Default is 0.01.
         objective_reshuffling: Option<f64>,
         /// Learning rate. Default is 0.1.
         learning_rate: Option<f64>,
-        /// A rebalance memory. Default is 500.
+        /// A rebalance memory. Default is 100.
         rebalance_memory: Option<usize>,
-        /// A rebalance count. Default is 2.
-        rebalance_count: Option<usize>,
         /// An exploration phase ratio. Default is 0.9.
         exploration_ratio: Option<f64>,
     },
@@ -433,6 +431,7 @@ fn configure_from_evolution(
     mut builder: ProblemConfigBuilder,
     problem: Arc<Problem>,
     environment: Arc<Environment>,
+    telemetry_config: &Option<TelemetryConfig>,
     population_config: &Option<EvolutionConfig>,
 ) -> Result<ProblemConfigBuilder, String> {
     if let Some(config) = population_config {
@@ -490,7 +489,6 @@ fn configure_from_evolution(
                     learning_rate,
                     selection_size,
                     rebalance_memory,
-                    rebalance_count,
                     exploration_ratio,
                 } => {
                     let mut config = RosomaxaConfig::new_with_defaults(default_selection_size);
@@ -518,9 +516,6 @@ fn configure_from_evolution(
                     if let Some(rebalance_memory) = rebalance_memory {
                         config.rebalance_memory = *rebalance_memory;
                     }
-                    if let Some(rebalance_count) = rebalance_count {
-                        config.rebalance_count = *rebalance_count;
-                    }
                     if let Some(exploration_ratio) = exploration_ratio {
                         config.exploration_ratio = *exploration_ratio;
                     }
@@ -529,7 +524,9 @@ fn configure_from_evolution(
                 }
             };
 
-            builder = builder.with_context(RefinementContext::new(problem, population, environment));
+            let telemetry_mode = get_telemetry_mode(environment.clone(), telemetry_config);
+
+            builder = builder.with_context(RefinementContext::new(problem, population, telemetry_mode, environment));
         }
     }
 
@@ -733,11 +730,7 @@ fn create_local_search(
     Arc::new(CompositeLocalOperator::new(operators, times.min, times.max))
 }
 
-fn configure_from_telemetry(
-    builder: ProblemConfigBuilder,
-    environment: Arc<Environment>,
-    telemetry_config: &Option<TelemetryConfig>,
-) -> ProblemConfigBuilder {
+fn get_telemetry_mode(environment: Arc<Environment>, telemetry_config: &Option<TelemetryConfig>) -> TelemetryMode {
     const LOG_BEST: usize = 100;
     const LOG_POPULATION: usize = 1000;
     const TRACK_POPULATION: usize = 1000;
@@ -755,7 +748,7 @@ fn configure_from_telemetry(
         }
     };
 
-    let telemetry_mode = match telemetry_config.as_ref().map(|t| (&t.progress, &t.metrics)) {
+    match telemetry_config.as_ref().map(|t| (&t.progress, &t.metrics)) {
         Some((None, Some(MetricsConfig { enabled, track_population }))) if *enabled => create_metrics(track_population),
         Some((Some(ProgressConfig { enabled, log_best, log_population, dump_population }), None)) if *enabled => {
             create_progress(log_best, log_population, dump_population)
@@ -776,9 +769,7 @@ fn configure_from_telemetry(
             _ => TelemetryMode::None,
         },
         _ => TelemetryMode::None,
-    };
-
-    builder.with_telemetry(Telemetry::new(telemetry_mode))
+    }
 }
 
 fn configure_from_environment(
@@ -835,8 +826,8 @@ pub fn create_builder_from_config(
     let mut builder =
         create_default_config_builder(problem.clone(), environment.clone()).with_init_solutions(solutions, None);
 
-    builder = configure_from_telemetry(builder, environment.clone(), &config.telemetry);
-    builder = configure_from_evolution(builder, problem.clone(), environment.clone(), &config.evolution)?;
+    builder =
+        configure_from_evolution(builder, problem.clone(), environment.clone(), &config.telemetry, &config.evolution)?;
     builder = configure_from_hyper(builder, problem, environment, &config.hyper)?;
     builder = configure_from_termination(builder, &config.termination);
 
