@@ -428,7 +428,7 @@ pub fn get_locations_serialized(problem: &Problem) -> Result<String, String> {
 
 /// Gets solution serialized in json.
 pub fn get_solution_serialized(problem: Arc<CoreProblem>, config: Config) -> Result<String, String> {
-    let (solution, cost, metrics) = create_builder_from_config(problem.clone(), &config)
+    let (solution, cost, metrics) = create_builder_from_config(problem.clone(), Default::default(), &config)
         .and_then(|builder| builder.build())
         .map(|config| Solver::new(problem.clone(), config))
         .and_then(|solver| solver.solve())
