@@ -3,7 +3,7 @@ use std::collections::HashSet;
 use std::fs::File;
 use std::io::BufReader;
 use vrp_pragmatic::format::problem::deserialize_locations;
-use vrp_pragmatic::format::FormatError;
+use vrp_pragmatic::format::{CoordIndex, FormatError};
 use vrp_pragmatic::validation::ValidationContext;
 
 #[test]
@@ -11,8 +11,9 @@ fn can_generate_problem_from_simple_prototype() {
     let reader = BufReader::new(File::open("../examples/data/pragmatic/simple.basic.problem.json").unwrap());
     let problem =
         generate_problem("pragmatic", Some(vec![reader]), None, 50, 4, None).map_err(|err| panic!("{}", err)).unwrap();
+    let coord_index = CoordIndex::new(&problem);
 
-    ValidationContext::new(&problem, None)
+    ValidationContext::new(&problem, None, &coord_index)
         .validate()
         .map_err(|err| panic!("{}", FormatError::format_many(&err, "\t\n")))
         .unwrap();
