@@ -25,7 +25,7 @@ fn can_run_analyze_clusters() {
         "--out-result",
         tmpfile.path().to_str().unwrap(),
     ];
-    let matches = get_analyze_app().get_matches_from_safe(args).unwrap();
+    let matches = get_analyze_app().try_get_matches_from(args).unwrap();
 
     run_analyze(&matches, |_| BufWriter::new(Box::new(DummyWrite {}))).unwrap();
 }
@@ -34,5 +34,5 @@ fn can_run_analyze_clusters() {
 fn can_detect_wrong_argument() {
     let args = vec!["analyze", "clusters", "solomon", PRAGMATIC_PROBLEM_PATH, "--out-result", "/some/path"];
 
-    assert!(get_analyze_app().get_matches_from_safe(args).is_err());
+    assert!(get_analyze_app().try_get_matches_from(args).is_err());
 }
